from setuptools import setup, find_packages

setup(
    name="szn-search-mlops-annot-labelling",
    version="0.0.1",
    description="Security placeholder package",
    long_description="This package is a security placeholder to prevent dependency confusion attacks.",
    long_description_content_type="text/plain",
    author="Security Team",
    author_email="security@company.com",
    packages=find_packages(),
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
    ],
    python_requires=">=3.6",
)